pub struct EstimationRequestBuilder<S: State = Empty> { /* private fields */ }Expand description
Use builder syntax to set the inputs and finish with build().
Implementations
Sourceimpl<S: State> EstimationRequestBuilder<S>
impl<S: State> EstimationRequestBuilder<S>
Sourcepub fn build(self) -> EstimationRequestwhere
S: IsComplete,
pub fn build(self) -> EstimationRequestwhere
S: IsComplete,
Finish building and return the requested object
Sourcepub fn pet_id(self, value: PetId) -> EstimationRequestBuilder<SetPetId<S>>where
S::PetId: IsUnset,
pub fn pet_id(self, value: PetId) -> EstimationRequestBuilder<SetPetId<S>>where
S::PetId: IsUnset,
Required.
Pet receiving the grooming or care service.
Sourcepub fn service(self, value: Service) -> EstimationRequestBuilder<SetService<S>>where
S::Service: IsUnset,
pub fn service(self, value: Service) -> EstimationRequestBuilder<SetService<S>>where
S::Service: IsUnset,
Required.
Requested service that drives scheduling and labor estimates.
Sourcepub fn breed(
self,
value: BreedCategory,
) -> EstimationRequestBuilder<SetBreed<S>>where
S::Breed: IsUnset,
pub fn breed(
self,
value: BreedCategory,
) -> EstimationRequestBuilder<SetBreed<S>>where
S::Breed: IsUnset,
Required.
Breed/coat class used to translate pet profile data into groomer labor demand.
Sourcepub fn coat(self, value: CoatCondition) -> EstimationRequestBuilder<SetCoat<S>>where
S::Coat: IsUnset,
pub fn coat(self, value: CoatCondition) -> EstimationRequestBuilder<SetCoat<S>>where
S::Coat: IsUnset,
Required.
Coat condition that can raise confidence risk or trigger groomer review.